# coding=utf-8
r"""
This code was generated by
\ / _    _  _|   _  _
 | (_)\/(_)(_|\/| |(/_  v1.0.0
      /       /
"""

from tests import IntegrationTestCase
from tests.holodeck import Request
from twilio.base import serialize
from twilio.base.exceptions import TwilioException
from twilio.http.response import Response


class InteractionTestCase(IntegrationTestCase):

    def test_fetch_request(self):
        self.holodeck.mock(Response(500, ''))

        with self.assertRaises(TwilioException):
            self.client.flex_api.v1.interaction("KDXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX").fetch()

        self.holodeck.assert_has_request(Request(
            'get',
            'https://flex-api.twilio.com/v1/Interactions/KDXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
        ))

    def test_fetch_response(self):
        self.holodeck.mock(Response(
            200,
            '''
            {
                "sid": "KDaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                "channel": {
                    "type": "sms",
                    "sid": "UOaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa"
                },
                "routing": {
                    "properties": {
                        "workflow_sid": "WWxx",
                        "attributes": "WWxx",
                        "task_channel_unique_name": "sms",
                        "routing_target": "WKXX",
                        "queue_name": "WQXX"
                    }
                },
                "url": "https://flex-api.twilio.com/v1/Interactions/KDaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                "links": {
                    "channels": "https://flex-api.twilio.com/v1/Interactions/KDaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa/Channels"
                }
            }
            '''
        ))

        actual = self.client.flex_api.v1.interaction("KDXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX").fetch()

        self.assertIsNotNone(actual)

    def test_create_request(self):
        self.holodeck.mock(Response(500, ''))

        with self.assertRaises(TwilioException):
            self.client.flex_api.v1.interaction.create(channel={}, routing={})

        values = {'Channel': serialize.object({}), 'Routing': serialize.object({}), }

        self.holodeck.assert_has_request(Request(
            'post',
            'https://flex-api.twilio.com/v1/Interactions',
            data=values,
        ))

    def test_create_response(self):
        self.holodeck.mock(Response(
            201,
            '''
            {
                "sid": "KDaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                "channel": {
                    "type": "sms",
                    "sid": "UOaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa"
                },
                "routing": {
                    "reservation": null,
                    "properties": {
                        "date_updated": 1634845217,
                        "task_queue_entered_date": 1634845217,
                        "workflow_name": "Default Fifo Workflow",
                        "age_in_queue": 0,
                        "task_channel_unique_name": "default",
                        "assignment_status": "pending",
                        "queue_name": "Sample Queue",
                        "assignmentCounter": 0,
                        "priority": 0,
                        "sid": "WTaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                        "workflow_sid": "WWaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                        "routing_target": "WKaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                        "reason": "",
                        "attributes": "{\\"customerAddress\\":\\"customer phone address\\",\\"flexChannelInviteSid\\":\\"KGaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa\\",\\"conversationSid\\":\\"CHaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa\\",\\"channelType\\":\\"sms\\",\\"customers\\":{\\"phone\\":\\"customer phone address\\",\\"name\\":\\"customer name\\"},\\"conversations\\":{\\"initiated_by\\":\\"customer\\",\\"conversation_id\\":\\"KDaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa\\",\\"media\\":[{\\"type\\":\\"ChatTranscript\\",\\"sid\\":\\"CHaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa\\"}]},\\"customerName\\":\\"customer name\\",\\"flexInteractionChannelSid\\":\\"UOaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa\\",\\"initiatedBy\\":\\"customer\\",\\"flexInteractionSid\\":\\"KDaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa\\",\\"direction\\":\\"inbound\\"}",
                        "task_channel_sid": "TCaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                        "age": 0,
                        "workspace_sid": "WSaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                        "account_sid": "ACaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                        "timeout": 86400,
                        "date_created": 1634845217,
                        "addons": "{}",
                        "queue_sid": "WQaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa"
                    }
                },
                "url": "https://flex-api.twilio.com/v1/Interactions/KDaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                "links": {
                    "channels": "https://flex-api.twilio.com/v1/Interactions/KDaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa/Channels"
                }
            }
            '''
        ))

        actual = self.client.flex_api.v1.interaction.create(channel={}, routing={})

        self.assertIsNotNone(actual)
